import type { LayoutServerLoad } from './$types';
import { Admin, Feedback, Report, User } from '$lib/server/database';
import { getSession } from '$lib/server/session';
import { redirect } from '@sveltejs/kit';
import { env } from '$env/dynamic/public';
import { Op } from 'sequelize';

export const load: LayoutServerLoad = async ({ route, cookies }) => {
	const session = getSession(cookies);

	if (session == null && route.id != '/admin/login')
		throw redirect(302, `${env.PUBLIC_BASE_PATH}/admin/login`);

	return {
		userCount: session?.permissions.users() ? await User.count() : null,
		reportCount: session?.permissions.reports()
			? await Report.count({ where: { draft: false, status: ['none', 'review'] } })
			: null,
		feedbackCount: session?.permissions.feedback()
			? await Feedback.count({ where: { content: { [Op.not]: null } } })
			: null,
		adminCount: session?.permissions.admin() ? await Admin.count() : null,
		settingsRead: session?.permissions.settings(),
		toolsRead: session?.permissions.tools(),
		self: session
			? JSON.parse(JSON.stringify(await Admin.findOne({ where: { id: session.userId } })))
			: null
	};
};
